GherkinScenario class
A parsed executable Gherkin scenario.
Constructors
-
GherkinScenario({required List<
GherkinTag> tags, required GherkinElement scenarioElement, List<GherkinStep> steps = const [], List<GherkinExamples> examples = const []}) -
Creates a parsed scenario.
const
Properties
-
examples
→ List<
GherkinExamples> -
Examples blocks for a scenario outline.
final
-
examplesBlocks
→ List<
GherkinExamples> -
Alias for examples retained for parser consumers.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenarioElement → GherkinElement
-
Parsed scenario element.
final
-
steps
→ List<
GherkinStep> -
Executable scenario steps.
final
-
Scenario tags.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited